# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetAccountResult',
    'AwaitableGetAccountResult',
    'get_account',
    'get_account_output',
]

@pulumi.output_type
class GetAccountResult:
    """
    A collection of values returned by getAccount.
    """
    def __init__(__self__, account_id=None, clusters=None, external_id=None, id=None, organization=None, rockset_user=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if clusters and not isinstance(clusters, list):
            raise TypeError("Expected argument 'clusters' to be a list")
        pulumi.set(__self__, "clusters", clusters)
        if external_id and not isinstance(external_id, str):
            raise TypeError("Expected argument 'external_id' to be a str")
        pulumi.set(__self__, "external_id", external_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if organization and not isinstance(organization, str):
            raise TypeError("Expected argument 'organization' to be a str")
        pulumi.set(__self__, "organization", organization)
        if rockset_user and not isinstance(rockset_user, str):
            raise TypeError("Expected argument 'rockset_user' to be a str")
        pulumi.set(__self__, "rockset_user", rockset_user)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> str:
        """
        The AWS account ID to reference in AWS policies.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter
    def clusters(self) -> Sequence['outputs.GetAccountClusterResult']:
        """
        The Rockset clusters available to this API key.
        """
        return pulumi.get(self, "clusters")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> str:
        """
        The external ID to use in AWS trust policies.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def organization(self) -> str:
        """
        The name of the organization for the API key.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter(name="rocksetUser")
    def rockset_user(self) -> str:
        """
        The name of the Rockset user used for AWS trust policies.
        """
        return pulumi.get(self, "rockset_user")


class AwaitableGetAccountResult(GetAccountResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccountResult(
            account_id=self.account_id,
            clusters=self.clusters,
            external_id=self.external_id,
            id=self.id,
            organization=self.organization,
            rockset_user=self.rockset_user)


def get_account(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAccountResult:
    """
    Gets information about the Rockset deployment for the specified api server.
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('rockset:index/getAccount:getAccount', __args__, opts=opts, typ=GetAccountResult).value

    return AwaitableGetAccountResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        clusters=pulumi.get(__ret__, 'clusters'),
        external_id=pulumi.get(__ret__, 'external_id'),
        id=pulumi.get(__ret__, 'id'),
        organization=pulumi.get(__ret__, 'organization'),
        rockset_user=pulumi.get(__ret__, 'rockset_user'))


@_utilities.lift_output_func(get_account)
def get_account_output(opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAccountResult]:
    """
    Gets information about the Rockset deployment for the specified api server.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['QueryLambdaTagArgs', 'QueryLambdaTag']

@pulumi.input_type
class QueryLambdaTagArgs:
    def __init__(__self__, *,
                 query_lambda: pulumi.Input[str],
                 version: pulumi.Input[str],
                 workspace: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a QueryLambdaTag resource.
        :param pulumi.Input[str] query_lambda: Unique identifier for the query lambda. Can contain alphanumeric or dash characters.
        :param pulumi.Input[str] version: Version of the query lambda this tag should point to.
        :param pulumi.Input[str] workspace: The name of the workspace the query lambda is in.
        :param pulumi.Input[str] name: Unique identifier for the tag. Can contain alphanumeric or dash characters.
        """
        pulumi.set(__self__, "query_lambda", query_lambda)
        pulumi.set(__self__, "version", version)
        pulumi.set(__self__, "workspace", workspace)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="queryLambda")
    def query_lambda(self) -> pulumi.Input[str]:
        """
        Unique identifier for the query lambda. Can contain alphanumeric or dash characters.
        """
        return pulumi.get(self, "query_lambda")

    @query_lambda.setter
    def query_lambda(self, value: pulumi.Input[str]):
        pulumi.set(self, "query_lambda", value)

    @property
    @pulumi.getter
    def version(self) -> pulumi.Input[str]:
        """
        Version of the query lambda this tag should point to.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: pulumi.Input[str]):
        pulumi.set(self, "version", value)

    @property
    @pulumi.getter
    def workspace(self) -> pulumi.Input[str]:
        """
        The name of the workspace the query lambda is in.
        """
        return pulumi.get(self, "workspace")

    @workspace.setter
    def workspace(self, value: pulumi.Input[str]):
        pulumi.set(self, "workspace", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Unique identifier for the tag. Can contain alphanumeric or dash characters.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _QueryLambdaTagState:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[str]] = None,
                 query_lambda: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[str]] = None,
                 workspace: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering QueryLambdaTag resources.
        :param pulumi.Input[str] name: Unique identifier for the tag. Can contain alphanumeric or dash characters.
        :param pulumi.Input[str] query_lambda: Unique identifier for the query lambda. Can contain alphanumeric or dash characters.
        :param pulumi.Input[str] version: Version of the query lambda this tag should point to.
        :param pulumi.Input[str] workspace: The name of the workspace the query lambda is in.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if query_lambda is not None:
            pulumi.set(__self__, "query_lambda", query_lambda)
        if version is not None:
            pulumi.set(__self__, "version", version)
        if workspace is not None:
            pulumi.set(__self__, "workspace", workspace)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Unique identifier for the tag. Can contain alphanumeric or dash characters.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="queryLambda")
    def query_lambda(self) -> Optional[pulumi.Input[str]]:
        """
        Unique identifier for the query lambda. Can contain alphanumeric or dash characters.
        """
        return pulumi.get(self, "query_lambda")

    @query_lambda.setter
    def query_lambda(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "query_lambda", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[str]]:
        """
        Version of the query lambda this tag should point to.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "version", value)

    @property
    @pulumi.getter
    def workspace(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the workspace the query lambda is in.
        """
        return pulumi.get(self, "workspace")

    @workspace.setter
    def workspace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "workspace", value)


class QueryLambdaTag(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 query_lambda: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[str]] = None,
                 workspace: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Rockset Query Lambda Tag.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: Unique identifier for the tag. Can contain alphanumeric or dash characters.
        :param pulumi.Input[str] query_lambda: Unique identifier for the query lambda. Can contain alphanumeric or dash characters.
        :param pulumi.Input[str] version: Version of the query lambda this tag should point to.
        :param pulumi.Input[str] workspace: The name of the workspace the query lambda is in.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: QueryLambdaTagArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Rockset Query Lambda Tag.

        :param str resource_name: The name of the resource.
        :param QueryLambdaTagArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(QueryLambdaTagArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 query_lambda: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[str]] = None,
                 workspace: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = QueryLambdaTagArgs.__new__(QueryLambdaTagArgs)

            __props__.__dict__["name"] = name
            if query_lambda is None and not opts.urn:
                raise TypeError("Missing required property 'query_lambda'")
            __props__.__dict__["query_lambda"] = query_lambda
            if version is None and not opts.urn:
                raise TypeError("Missing required property 'version'")
            __props__.__dict__["version"] = version
            if workspace is None and not opts.urn:
                raise TypeError("Missing required property 'workspace'")
            __props__.__dict__["workspace"] = workspace
        super(QueryLambdaTag, __self__).__init__(
            'rockset:index/queryLambdaTag:QueryLambdaTag',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            name: Optional[pulumi.Input[str]] = None,
            query_lambda: Optional[pulumi.Input[str]] = None,
            version: Optional[pulumi.Input[str]] = None,
            workspace: Optional[pulumi.Input[str]] = None) -> 'QueryLambdaTag':
        """
        Get an existing QueryLambdaTag resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: Unique identifier for the tag. Can contain alphanumeric or dash characters.
        :param pulumi.Input[str] query_lambda: Unique identifier for the query lambda. Can contain alphanumeric or dash characters.
        :param pulumi.Input[str] version: Version of the query lambda this tag should point to.
        :param pulumi.Input[str] workspace: The name of the workspace the query lambda is in.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _QueryLambdaTagState.__new__(_QueryLambdaTagState)

        __props__.__dict__["name"] = name
        __props__.__dict__["query_lambda"] = query_lambda
        __props__.__dict__["version"] = version
        __props__.__dict__["workspace"] = workspace
        return QueryLambdaTag(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Unique identifier for the tag. Can contain alphanumeric or dash characters.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="queryLambda")
    def query_lambda(self) -> pulumi.Output[str]:
        """
        Unique identifier for the query lambda. Can contain alphanumeric or dash characters.
        """
        return pulumi.get(self, "query_lambda")

    @property
    @pulumi.getter
    def version(self) -> pulumi.Output[str]:
        """
        Version of the query lambda this tag should point to.
        """
        return pulumi.get(self, "version")

    @property
    @pulumi.getter
    def workspace(self) -> pulumi.Output[str]:
        """
        The name of the workspace the query lambda is in.
        """
        return pulumi.get(self, "workspace")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['GcsIntegrationArgs', 'GcsIntegration']

@pulumi.input_type
class GcsIntegrationArgs:
    def __init__(__self__, *,
                 service_account_key: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a GcsIntegration resource.
        :param pulumi.Input[str] service_account_key: The GCP service account key JSON.
        :param pulumi.Input[str] description: Text describing the integration.
        :param pulumi.Input[str] name: Unique identifier for the integration. Can contain alphanumeric or dash characters.
        """
        pulumi.set(__self__, "service_account_key", service_account_key)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="serviceAccountKey")
    def service_account_key(self) -> pulumi.Input[str]:
        """
        The GCP service account key JSON.
        """
        return pulumi.get(self, "service_account_key")

    @service_account_key.setter
    def service_account_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "service_account_key", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Text describing the integration.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Unique identifier for the integration. Can contain alphanumeric or dash characters.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _GcsIntegrationState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 service_account_key: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering GcsIntegration resources.
        :param pulumi.Input[str] description: Text describing the integration.
        :param pulumi.Input[str] name: Unique identifier for the integration. Can contain alphanumeric or dash characters.
        :param pulumi.Input[str] service_account_key: The GCP service account key JSON.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if service_account_key is not None:
            pulumi.set(__self__, "service_account_key", service_account_key)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Text describing the integration.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Unique identifier for the integration. Can contain alphanumeric or dash characters.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="serviceAccountKey")
    def service_account_key(self) -> Optional[pulumi.Input[str]]:
        """
        The GCP service account key JSON.
        """
        return pulumi.get(self, "service_account_key")

    @service_account_key.setter
    def service_account_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_account_key", value)


class GcsIntegration(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 service_account_key: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Rockset GCS Integration.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Text describing the integration.
        :param pulumi.Input[str] name: Unique identifier for the integration. Can contain alphanumeric or dash characters.
        :param pulumi.Input[str] service_account_key: The GCP service account key JSON.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GcsIntegrationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Rockset GCS Integration.

        :param str resource_name: The name of the resource.
        :param GcsIntegrationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GcsIntegrationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 service_account_key: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GcsIntegrationArgs.__new__(GcsIntegrationArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if service_account_key is None and not opts.urn:
                raise TypeError("Missing required property 'service_account_key'")
            __props__.__dict__["service_account_key"] = service_account_key
        super(GcsIntegration, __self__).__init__(
            'rockset:index/gcsIntegration:GcsIntegration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            service_account_key: Optional[pulumi.Input[str]] = None) -> 'GcsIntegration':
        """
        Get an existing GcsIntegration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Text describing the integration.
        :param pulumi.Input[str] name: Unique identifier for the integration. Can contain alphanumeric or dash characters.
        :param pulumi.Input[str] service_account_key: The GCP service account key JSON.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GcsIntegrationState.__new__(_GcsIntegrationState)

        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["service_account_key"] = service_account_key
        return GcsIntegration(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Text describing the integration.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Unique identifier for the integration. Can contain alphanumeric or dash characters.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="serviceAccountKey")
    def service_account_key(self) -> pulumi.Output[str]:
        """
        The GCP service account key JSON.
        """
        return pulumi.get(self, "service_account_key")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'DynamodbCollectionSourceArgs',
    'GcsCollectionSourceArgs',
    'GcsCollectionSourceCsvArgs',
    'GcsCollectionSourceXmlArgs',
    'KafkaCollectionSourceArgs',
    'KafkaCollectionSourceStatusArgs',
    'KafkaCollectionSourceStatusPartitionArgs',
    'KinesisCollectionSourceArgs',
    'MongodbCollectionSourceArgs',
    'QueryLambdaSqlArgs',
    'QueryLambdaSqlDefaultParameterArgs',
    'RolePrivilegeArgs',
    'S3CollectionSourceArgs',
    'S3CollectionSourceCsvArgs',
    'S3CollectionSourceXmlArgs',
]

@pulumi.input_type
class DynamodbCollectionSourceArgs:
    def __init__(__self__, *,
                 integration_name: pulumi.Input[str],
                 table_name: pulumi.Input[str],
                 aws_region: Optional[pulumi.Input[str]] = None,
                 rcu: Optional[pulumi.Input[int]] = None,
                 scan_end_time: Optional[pulumi.Input[str]] = None,
                 scan_records_processed: Optional[pulumi.Input[int]] = None,
                 scan_start_time: Optional[pulumi.Input[str]] = None,
                 scan_total_records: Optional[pulumi.Input[int]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 stream_last_processed_at: Optional[pulumi.Input[str]] = None,
                 use_scan_api: Optional[pulumi.Input[bool]] = None):
        """
        :param pulumi.Input[str] integration_name: The name of the Rockset DynamoDB integration.
        :param pulumi.Input[str] table_name: Name of DynamoDB table containing data.
        :param pulumi.Input[str] aws_region: AWS region name of DynamoDB table, by default us-west-2 is used.
        :param pulumi.Input[int] rcu: Max RCU usage for scan.
        :param pulumi.Input[str] scan_end_time: DynamoDB scan end time.
        :param pulumi.Input[int] scan_records_processed: Number of records inserted using scan.
        :param pulumi.Input[str] scan_start_time: DynamoDB scan start time.
        :param pulumi.Input[int] scan_total_records: Number of records in DynamoDB table at time of scan.
        :param pulumi.Input[str] state: State of current ingest for this table.
        :param pulumi.Input[str] stream_last_processed_at: ISO-8601 date when source was last processed.
        :param pulumi.Input[bool] use_scan_api: Whether the initial table scan should use the DynamoDB scan API. If false, export will be performed using an S3 bucket.
        """
        pulumi.set(__self__, "integration_name", integration_name)
        pulumi.set(__self__, "table_name", table_name)
        if aws_region is not None:
            pulumi.set(__self__, "aws_region", aws_region)
        if rcu is not None:
            pulumi.set(__self__, "rcu", rcu)
        if scan_end_time is not None:
            pulumi.set(__self__, "scan_end_time", scan_end_time)
        if scan_records_processed is not None:
            pulumi.set(__self__, "scan_records_processed", scan_records_processed)
        if scan_start_time is not None:
            pulumi.set(__self__, "scan_start_time", scan_start_time)
        if scan_total_records is not None:
            pulumi.set(__self__, "scan_total_records", scan_total_records)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if stream_last_processed_at is not None:
            pulumi.set(__self__, "stream_last_processed_at", stream_last_processed_at)
        if use_scan_api is not None:
            pulumi.set(__self__, "use_scan_api", use_scan_api)

    @property
    @pulumi.getter(name="integrationName")
    def integration_name(self) -> pulumi.Input[str]:
        """
        The name of the Rockset DynamoDB integration.
        """
        return pulumi.get(self, "integration_name")

    @integration_name.setter
    def integration_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "integration_name", value)

    @property
    @pulumi.getter(name="tableName")
    def table_name(self) -> pulumi.Input[str]:
        """
        Name of DynamoDB table containing data.
        """
        return pulumi.get(self, "table_name")

    @table_name.setter
    def table_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "table_name", value)

    @property
    @pulumi.getter(name="awsRegion")
    def aws_region(self) -> Optional[pulumi.Input[str]]:
        """
        AWS region name of DynamoDB table, by default us-west-2 is used.
        """
        return pulumi.get(self, "aws_region")

    @aws_region.setter
    def aws_region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aws_region", value)

    @property
    @pulumi.getter
    def rcu(self) -> Optional[pulumi.Input[int]]:
        """
        Max RCU usage for scan.
        """
        return pulumi.get(self, "rcu")

    @rcu.setter
    def rcu(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "rcu", value)

    @property
    @pulumi.getter(name="scanEndTime")
    def scan_end_time(self) -> Optional[pulumi.Input[str]]:
        """
        DynamoDB scan end time.
        """
        return pulumi.get(self, "scan_end_time")

    @scan_end_time.setter
    def scan_end_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "scan_end_time", value)

    @property
    @pulumi.getter(name="scanRecordsProcessed")
    def scan_records_processed(self) -> Optional[pulumi.Input[int]]:
        """
        Number of records inserted using scan.
        """
        return pulumi.get(self, "scan_records_processed")

    @scan_records_processed.setter
    def scan_records_processed(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "scan_records_processed", value)

    @property
    @pulumi.getter(name="scanStartTime")
    def scan_start_time(self) -> Optional[pulumi.Input[str]]:
        """
        DynamoDB scan start time.
        """
        return pulumi.get(self, "scan_start_time")

    @scan_start_time.setter
    def scan_start_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "scan_start_time", value)

    @property
    @pulumi.getter(name="scanTotalRecords")
    def scan_total_records(self) -> Optional[pulumi.Input[int]]:
        """
        Number of records in DynamoDB table at time of scan.
        """
        return pulumi.get(self, "scan_total_records")

    @scan_total_records.setter
    def scan_total_records(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "scan_total_records", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        State of current ingest for this table.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="streamLastProcessedAt")
    def stream_last_processed_at(self) -> Optional[pulumi.Input[str]]:
        """
        ISO-8601 date when source was last processed.
        """
        return pulumi.get(self, "stream_last_processed_at")

    @stream_last_processed_at.setter
    def stream_last_processed_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "stream_last_processed_at", value)

    @property
    @pulumi.getter(name="useScanApi")
    def use_scan_api(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the initial table scan should use the DynamoDB scan API. If false, export will be performed using an S3 bucket.
        """
        return pulumi.get(self, "use_scan_api")

    @use_scan_api.setter
    def use_scan_api(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "use_scan_api", value)


@pulumi.input_type
class GcsCollectionSourceArgs:
    def __init__(__self__, *,
                 bucket: pulumi.Input[str],
                 format: pulumi.Input[str],
                 integration_name: pulumi.Input[str],
                 csv: Optional[pulumi.Input['GcsCollectionSourceCsvArgs']] = None,
                 prefix: Optional[pulumi.Input[str]] = None,
                 xml: Optional[pulumi.Input['GcsCollectionSourceXmlArgs']] = None):
        """
        :param pulumi.Input[str] bucket: GCS bucket containing the target data.
        :param pulumi.Input[str] format: Format of the data. One of: json, csv, xml. xml and csv blocks can only be set for their respective formats.
        :param pulumi.Input[str] integration_name: The name of the Rockset GCS integration.
        :param pulumi.Input[str] prefix: Simple path prefix to GCS key.
        """
        pulumi.set(__self__, "bucket", bucket)
        pulumi.set(__self__, "format", format)
        pulumi.set(__self__, "integration_name", integration_name)
        if csv is not None:
            pulumi.set(__self__, "csv", csv)
        if prefix is not None:
            pulumi.set(__self__, "prefix", prefix)
        if xml is not None:
            pulumi.set(__self__, "xml", xml)

    @property
    @pulumi.getter
    def bucket(self) -> pulumi.Input[str]:
        """
        GCS bucket containing the target data.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: pulumi.Input[str]):
        pulumi.set(self, "bucket", value)

    @property
    @pulumi.getter
    def format(self) -> pulumi.Input[str]:
        """
        Format of the data. One of: json, csv, xml. xml and csv blocks can only be set for their respective formats.
        """
        return pulumi.get(self, "format")

    @format.setter
    def format(self, value: pulumi.Input[str]):
        pulumi.set(self, "format", value)

    @property
    @pulumi.getter(name="integrationName")
    def integration_name(self) -> pulumi.Input[str]:
        """
        The name of the Rockset GCS integration.
        """
        return pulumi.get(self, "integration_name")

    @integration_name.setter
    def integration_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "integration_name", value)

    @property
    @pulumi.getter
    def csv(self) -> Optional[pulumi.Input['GcsCollectionSourceCsvArgs']]:
        return pulumi.get(self, "csv")

    @csv.setter
    def csv(self, value: Optional[pulumi.Input['GcsCollectionSourceCsvArgs']]):
        pulumi.set(self, "csv", value)

    @property
    @pulumi.getter
    def prefix(self) -> Optional[pulumi.Input[str]]:
        """
        Simple path prefix to GCS key.
        """
        return pulumi.get(self, "prefix")

    @prefix.setter
    def prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "prefix", value)

    @property
    @pulumi.getter
    def xml(self) -> Optional[pulumi.Input['GcsCollectionSourceXmlArgs']]:
        return pulumi.get(self, "xml")

    @xml.setter
    def xml(self, value: Optional[pulumi.Input['GcsCollectionSourceXmlArgs']]):
        pulumi.set(self, "xml", value)


@pulumi.input_type
class GcsCollectionSourceCsvArgs:
    def __init__(__self__, *,
                 column_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 column_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 encoding: Optional[pulumi.Input[str]] = None,
                 escape_char: Optional[pulumi.Input[str]] = None,
                 first_line_as_column_names: Optional[pulumi.Input[bool]] = None,
                 quote_char: Optional[pulumi.Input[str]] = None,
                 separator: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[str]]] column_names: The names of the columns.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] column_types: The types of the columns.
        :param pulumi.Input[str] encoding: Can be one of: UTF-8, ISO*8859*1, UTF-16.
        :param pulumi.Input[str] escape_char: Escape character removes any special meaning from the character that follows it. Defaults to backslash.
        :param pulumi.Input[bool] first_line_as_column_names: If the first line in every object specifies the column names.
        :param pulumi.Input[str] quote_char: Character within which a cell value is enclosed. Defaults to double quote.
        :param pulumi.Input[str] separator: A single character that is the column separator.
        """
        if column_names is not None:
            pulumi.set(__self__, "column_names", column_names)
        if column_types is not None:
            pulumi.set(__self__, "column_types", column_types)
        if encoding is not None:
            pulumi.set(__self__, "encoding", encoding)
        if escape_char is not None:
            pulumi.set(__self__, "escape_char", escape_char)
        if first_line_as_column_names is not None:
            pulumi.set(__self__, "first_line_as_column_names", first_line_as_column_names)
        if quote_char is not None:
            pulumi.set(__self__, "quote_char", quote_char)
        if separator is not None:
            pulumi.set(__self__, "separator", separator)

    @property
    @pulumi.getter(name="columnNames")
    def column_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The names of the columns.
        """
        return pulumi.get(self, "column_names")

    @column_names.setter
    def column_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "column_names", value)

    @property
    @pulumi.getter(name="columnTypes")
    def column_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The types of the columns.
        """
        return pulumi.get(self, "column_types")

    @column_types.setter
    def column_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "column_types", value)

    @property
    @pulumi.getter
    def encoding(self) -> Optional[pulumi.Input[str]]:
        """
        Can be one of: UTF-8, ISO*8859*1, UTF-16.
        """
        return pulumi.get(self, "encoding")

    @encoding.setter
    def encoding(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "encoding", value)

    @property
    @pulumi.getter(name="escapeChar")
    def escape_char(self) -> Optional[pulumi.Input[str]]:
        """
        Escape character removes any special meaning from the character that follows it. Defaults to backslash.
        """
        return pulumi.get(self, "escape_char")

    @escape_char.setter
    def escape_char(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "escape_char", value)

    @property
    @pulumi.getter(name="firstLineAsColumnNames")
    def first_line_as_column_names(self) -> Optional[pulumi.Input[bool]]:
        """
        If the first line in every object specifies the column names.
        """
        return pulumi.get(self, "first_line_as_column_names")

    @first_line_as_column_names.setter
    def first_line_as_column_names(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "first_line_as_column_names", value)

    @property
    @pulumi.getter(name="quoteChar")
    def quote_char(self) -> Optional[pulumi.Input[str]]:
        """
        Character within which a cell value is enclosed. Defaults to double quote.
        """
        return pulumi.get(self, "quote_char")

    @quote_char.setter
    def quote_char(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "quote_char", value)

    @property
    @pulumi.getter
    def separator(self) -> Optional[pulumi.Input[str]]:
        """
        A single character that is the column separator.
        """
        return pulumi.get(self, "separator")

    @separator.setter
    def separator(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "separator", value)


@pulumi.input_type
class GcsCollectionSourceXmlArgs:
    def __init__(__self__, *,
                 attribute_prefix: Optional[pulumi.Input[str]] = None,
                 doc_tag: Optional[pulumi.Input[str]] = None,
                 encoding: Optional[pulumi.Input[str]] = None,
                 root_tag: Optional[pulumi.Input[str]] = None,
                 value_tag: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] attribute_prefix: Tag to differentiate between attributes and elements.
        :param pulumi.Input[str] doc_tag: Tags with which documents are identified
        :param pulumi.Input[str] encoding: Can be one of: UTF-8, ISO*8859*1, UTF-16.
        :param pulumi.Input[str] root_tag: Tag until which xml is ignored.
        :param pulumi.Input[str] value_tag: Tag used for the value when there are attributes in the element having no child.
        """
        if attribute_prefix is not None:
            pulumi.set(__self__, "attribute_prefix", attribute_prefix)
        if doc_tag is not None:
            pulumi.set(__self__, "doc_tag", doc_tag)
        if encoding is not None:
            pulumi.set(__self__, "encoding", encoding)
        if root_tag is not None:
            pulumi.set(__self__, "root_tag", root_tag)
        if value_tag is not None:
            pulumi.set(__self__, "value_tag", value_tag)

    @property
    @pulumi.getter(name="attributePrefix")
    def attribute_prefix(self) -> Optional[pulumi.Input[str]]:
        """
        Tag to differentiate between attributes and elements.
        """
        return pulumi.get(self, "attribute_prefix")

    @attribute_prefix.setter
    def attribute_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "attribute_prefix", value)

    @property
    @pulumi.getter(name="docTag")
    def doc_tag(self) -> Optional[pulumi.Input[str]]:
        """
        Tags with which documents are identified
        """
        return pulumi.get(self, "doc_tag")

    @doc_tag.setter
    def doc_tag(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "doc_tag", value)

    @property
    @pulumi.getter
    def encoding(self) -> Optional[pulumi.Input[str]]:
        """
        Can be one of: UTF-8, ISO*8859*1, UTF-16.
        """
        return pulumi.get(self, "encoding")

    @encoding.setter
    def encoding(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "encoding", value)

    @property
    @pulumi.getter(name="rootTag")
    def root_tag(self) -> Optional[pulumi.Input[str]]:
        """
        Tag until which xml is ignored.
        """
        return pulumi.get(self, "root_tag")

    @root_tag.setter
    def root_tag(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "root_tag", value)

    @property
    @pulumi.getter(name="valueTag")
    def value_tag(self) -> Optional[pulumi.Input[str]]:
        """
        Tag used for the value when there are attributes in the element having no child.
        """
        return pulumi.get(self, "value_tag")

    @value_tag.setter
    def value_tag(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value_tag", value)


@pulumi.input_type
class KafkaCollectionSourceArgs:
    def __init__(__self__, *,
                 integration_name: pulumi.Input[str],
                 topic_name: pulumi.Input[str],
                 consumer_group_id: Optional[pulumi.Input[str]] = None,
                 offset_reset_policy: Optional[pulumi.Input[str]] = None,
                 statuses: Optional[pulumi.Input[Sequence[pulumi.Input['KafkaCollectionSourceStatusArgs']]]] = None,
                 use_v3: Optional[pulumi.Input[bool]] = None):
        """
        :param pulumi.Input[str] integration_name: The name of the Rockset Kafka integration.
        :param pulumi.Input[str] topic_name: Name of Kafka topic to be tailed.
        :param pulumi.Input[str] consumer_group_id: The Kafka consumer group Id being used.
        :param pulumi.Input[str] offset_reset_policy: The offset reset policy. Possible values: LATEST, EARLIEST. Only valid with v3 collections.
        :param pulumi.Input[bool] use_v3: Whether to use v3 integration. Required if the kafka integration uses v3.
        """
        pulumi.set(__self__, "integration_name", integration_name)
        pulumi.set(__self__, "topic_name", topic_name)
        if consumer_group_id is not None:
            pulumi.set(__self__, "consumer_group_id", consumer_group_id)
        if offset_reset_policy is not None:
            pulumi.set(__self__, "offset_reset_policy", offset_reset_policy)
        if statuses is not None:
            pulumi.set(__self__, "statuses", statuses)
        if use_v3 is not None:
            pulumi.set(__self__, "use_v3", use_v3)

    @property
    @pulumi.getter(name="integrationName")
    def integration_name(self) -> pulumi.Input[str]:
        """
        The name of the Rockset Kafka integration.
        """
        return pulumi.get(self, "integration_name")

    @integration_name.setter
    def integration_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "integration_name", value)

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> pulumi.Input[str]:
        """
        Name of Kafka topic to be tailed.
        """
        return pulumi.get(self, "topic_name")

    @topic_name.setter
    def topic_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "topic_name", value)

    @property
    @pulumi.getter(name="consumerGroupId")
    def consumer_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Kafka consumer group Id being used.
        """
        return pulumi.get(self, "consumer_group_id")

    @consumer_group_id.setter
    def consumer_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "consumer_group_id", value)

    @property
    @pulumi.getter(name="offsetResetPolicy")
    def offset_reset_policy(self) -> Optional[pulumi.Input[str]]:
        """
        The offset reset policy. Possible values: LATEST, EARLIEST. Only valid with v3 collections.
        """
        return pulumi.get(self, "offset_reset_policy")

    @offset_reset_policy.setter
    def offset_reset_policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "offset_reset_policy", value)

    @property
    @pulumi.getter
    def statuses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['KafkaCollectionSourceStatusArgs']]]]:
        return pulumi.get(self, "statuses")

    @statuses.setter
    def statuses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['KafkaCollectionSourceStatusArgs']]]]):
        pulumi.set(self, "statuses", value)

    @property
    @pulumi.getter(name="useV3")
    def use_v3(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to use v3 integration. Required if the kafka integration uses v3.
        """
        return pulumi.get(self, "use_v3")

    @use_v3.setter
    def use_v3(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "use_v3", value)


@pulumi.input_type
class KafkaCollectionSourceStatusArgs:
    def __init__(__self__, *,
                 documents_processed: Optional[pulumi.Input[int]] = None,
                 last_consumed_time: Optional[pulumi.Input[str]] = None,
                 partitions: Optional[pulumi.Input[Sequence[pulumi.Input['KafkaCollectionSourceStatusPartitionArgs']]]] = None,
                 state: Optional[pulumi.Input[str]] = None):
        if documents_processed is not None:
            pulumi.set(__self__, "documents_processed", documents_processed)
        if last_consumed_time is not None:
            pulumi.set(__self__, "last_consumed_time", last_consumed_time)
        if partitions is not None:
            pulumi.set(__self__, "partitions", partitions)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="documentsProcessed")
    def documents_processed(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "documents_processed")

    @documents_processed.setter
    def documents_processed(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "documents_processed", value)

    @property
    @pulumi.getter(name="lastConsumedTime")
    def last_consumed_time(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "last_consumed_time")

    @last_consumed_time.setter
    def last_consumed_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_consumed_time", value)

    @property
    @pulumi.getter
    def partitions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['KafkaCollectionSourceStatusPartitionArgs']]]]:
        return pulumi.get(self, "partitions")

    @partitions.setter
    def partitions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['KafkaCollectionSourceStatusPartitionArgs']]]]):
        pulumi.set(self, "partitions", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)


@pulumi.input_type
class KafkaCollectionSourceStatusPartitionArgs:
    def __init__(__self__, *,
                 offset_lag: Optional[pulumi.Input[int]] = None,
                 partition_number: Optional[pulumi.Input[int]] = None,
                 partition_offset: Optional[pulumi.Input[int]] = None):
        if offset_lag is not None:
            pulumi.set(__self__, "offset_lag", offset_lag)
        if partition_number is not None:
            pulumi.set(__self__, "partition_number", partition_number)
        if partition_offset is not None:
            pulumi.set(__self__, "partition_offset", partition_offset)

    @property
    @pulumi.getter(name="offsetLag")
    def offset_lag(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "offset_lag")

    @offset_lag.setter
    def offset_lag(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "offset_lag", value)

    @property
    @pulumi.getter(name="partitionNumber")
    def partition_number(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "partition_number")

    @partition_number.setter
    def partition_number(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "partition_number", value)

    @property
    @pulumi.getter(name="partitionOffset")
    def partition_offset(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "partition_offset")

    @partition_offset.setter
    def partition_offset(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "partition_offset", value)


@pulumi.input_type
class KinesisCollectionSourceArgs:
    def __init__(__self__, *,
                 format: pulumi.Input[str],
                 integration_name: pulumi.Input[str],
                 stream_name: pulumi.Input[str],
                 aws_region: Optional[pulumi.Input[str]] = None,
                 dms_primary_keys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[str] format: Format of the data. One of: json, mysql, postgres. dms*primary*keys list can only be set for mysql or postgres.
        :param pulumi.Input[str] integration_name: The name of the Rockset Kinesis integration.
        :param pulumi.Input[str] stream_name: Name of Kinesis stream.
        :param pulumi.Input[str] aws_region: AWS region name for the Kinesis stream, by default us-west-2 is used
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dms_primary_keys: Set of fields that correspond to a DMS primary key. Can only be set if format is mysql or postgres.
        """
        pulumi.set(__self__, "format", format)
        pulumi.set(__self__, "integration_name", integration_name)
        pulumi.set(__self__, "stream_name", stream_name)
        if aws_region is not None:
            pulumi.set(__self__, "aws_region", aws_region)
        if dms_primary_keys is not None:
            pulumi.set(__self__, "dms_primary_keys", dms_primary_keys)

    @property
    @pulumi.getter
    def format(self) -> pulumi.Input[str]:
        """
        Format of the data. One of: json, mysql, postgres. dms*primary*keys list can only be set for mysql or postgres.
        """
        return pulumi.get(self, "format")

    @format.setter
    def format(self, value: pulumi.Input[str]):
        pulumi.set(self, "format", value)

    @property
    @pulumi.getter(name="integrationName")
    def integration_name(self) -> pulumi.Input[str]:
        """
        The name of the Rockset Kinesis integration.
        """
        return pulumi.get(self, "integration_name")

    @integration_name.setter
    def integration_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "integration_name", value)

    @property
    @pulumi.getter(name="streamName")
    def stream_name(self) -> pulumi.Input[str]:
        """
        Name of Kinesis stream.
        """
        return pulumi.get(self, "stream_name")

    @stream_name.setter
    def stream_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "stream_name", value)

    @property
    @pulumi.getter(name="awsRegion")
    def aws_region(self) -> Optional[pulumi.Input[str]]:
        """
        AWS region name for the Kinesis stream, by default us-west-2 is used
        """
        return pulumi.get(self, "aws_region")

    @aws_region.setter
    def aws_region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "aws_region", value)

    @property
    @pulumi.getter(name="dmsPrimaryKeys")
    def dms_primary_keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Set of fields that correspond to a DMS primary key. Can only be set if format is mysql or postgres.
        """
        return pulumi.get(self, "dms_primary_keys")

    @dms_primary_keys.setter
    def dms_primary_keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "dms_primary_keys", value)


@pulumi.input_type
class MongodbCollectionSourceArgs:
    def __init__(__self__, *,
                 collection_name: pulumi.Input[str],
                 database_name: pulumi.Input[str],
                 integration_name: pulumi.Input[str],
                 retrieve_full_document: Optional[pulumi.Input[bool]] = None,
                 scan_end_time: Optional[pulumi.Input[str]] = None,
                 scan_records_processed: Optional[pulumi.Input[int]] = None,
                 scan_start_time: Optional[pulumi.Input[str]] = None,
                 scan_total_records: Optional[pulumi.Input[int]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 stream_last_delete_processed_at: Optional[pulumi.Input[str]] = None,
                 stream_last_insert_processed_at: Optional[pulumi.Input[str]] = None,
                 stream_last_update_processed_at: Optional[pulumi.Input[str]] = None,
                 stream_records_deleted: Optional[pulumi.Input[int]] = None,
                 stream_records_inserted: Optional[pulumi.Input[int]] = None,
                 stream_records_updated: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[str] collection_name: MongoDB collection name of the target collection.
        :param pulumi.Input[str] database_name: MongoDB database name containing the target collection.
        :param pulumi.Input[str] integration_name: The name of the Rockset MongoDB integration.
        :param pulumi.Input[str] scan_end_time: MongoDB scan end time.
        :param pulumi.Input[int] scan_records_processed: Number of records inserted using scan.
        :param pulumi.Input[str] scan_start_time: MongoDB scan start time.
        :param pulumi.Input[int] scan_total_records: Number of records in MongoDB table at time of scan.
        :param pulumi.Input[str] state: State of current ingest for this table.
        :param pulumi.Input[str] stream_last_delete_processed_at: ISO-8601 date when delete from source was last processed.
        :param pulumi.Input[str] stream_last_insert_processed_at: ISO-8601 date when new insert from source was last processed.
        :param pulumi.Input[str] stream_last_update_processed_at: ISO-8601 date when update from source was last processed.
        :param pulumi.Input[int] stream_records_deleted: Number of new records deleted using stream.
        :param pulumi.Input[int] stream_records_inserted: Number of new records inserted using stream.
        :param pulumi.Input[int] stream_records_updated: Number of new records updated using stream.
        """
        pulumi.set(__self__, "collection_name", collection_name)
        pulumi.set(__self__, "database_name", database_name)
        pulumi.set(__self__, "integration_name", integration_name)
        if retrieve_full_document is not None:
            pulumi.set(__self__, "retrieve_full_document", retrieve_full_document)
        if scan_end_time is not None:
            pulumi.set(__self__, "scan_end_time", scan_end_time)
        if scan_records_processed is not None:
            pulumi.set(__self__, "scan_records_processed", scan_records_processed)
        if scan_start_time is not None:
            pulumi.set(__self__, "scan_start_time", scan_start_time)
        if scan_total_records is not None:
            pulumi.set(__self__, "scan_total_records", scan_total_records)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if stream_last_delete_processed_at is not None:
            pulumi.set(__self__, "stream_last_delete_processed_at", stream_last_delete_processed_at)
        if stream_last_insert_processed_at is not None:
            pulumi.set(__self__, "stream_last_insert_processed_at", stream_last_insert_processed_at)
        if stream_last_update_processed_at is not None:
            pulumi.set(__self__, "stream_last_update_processed_at", stream_last_update_processed_at)
        if stream_records_deleted is not None:
            pulumi.set(__self__, "stream_records_deleted", stream_records_deleted)
        if stream_records_inserted is not None:
            pulumi.set(__self__, "stream_records_inserted", stream_records_inserted)
        if stream_records_updated is not None:
            pulumi.set(__self__, "stream_records_updated", stream_records_updated)

    @property
    @pulumi.getter(name="collectionName")
    def collection_name(self) -> pulumi.Input[str]:
        """
        MongoDB collection name of the target collection.
        """
        return pulumi.get(self, "collection_name")

    @collection_name.setter
    def collection_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "collection_name", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Input[str]:
        """
        MongoDB database name containing the target collection.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter(name="integrationName")
    def integration_name(self) -> pulumi.Input[str]:
        """
        The name of the Rockset MongoDB integration.
        """
        return pulumi.get(self, "integration_name")

    @integration_name.setter
    def integration_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "integration_name", value)

    @property
    @pulumi.getter(name="retrieveFullDocument")
    def retrieve_full_document(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "retrieve_full_document")

    @retrieve_full_document.setter
    def retrieve_full_document(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "retrieve_full_document", value)

    @property
    @pulumi.getter(name="scanEndTime")
    def scan_end_time(self) -> Optional[pulumi.Input[str]]:
        """
        MongoDB scan end time.
        """
        return pulumi.get(self, "scan_end_time")

    @scan_end_time.setter
    def scan_end_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "scan_end_time", value)

    @property
    @pulumi.getter(name="scanRecordsProcessed")
    def scan_records_processed(self) -> Optional[pulumi.Input[int]]:
        """
        Number of records inserted using scan.
        """
        return pulumi.get(self, "scan_records_processed")

    @scan_records_processed.setter
    def scan_records_processed(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "scan_records_processed", value)

    @property
    @pulumi.getter(name="scanStartTime")
    def scan_start_time(self) -> Optional[pulumi.Input[str]]:
        """
        MongoDB scan start time.
        """
        return pulumi.get(self, "scan_start_time")

    @scan_start_time.setter
    def scan_start_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "scan_start_time", value)

    @property
    @pulumi.getter(name="scanTotalRecords")
    def scan_total_records(self) -> Optional[pulumi.Input[int]]:
        """
        Number of records in MongoDB table at time of scan.
        """
        return pulumi.get(self, "scan_total_records")

    @scan_total_records.setter
    def scan_total_records(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "scan_total_records", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        State of current ingest for this table.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="streamLastDeleteProcessedAt")
    def stream_last_delete_processed_at(self) -> Optional[pulumi.Input[str]]:
        """
        ISO-8601 date when delete from source was last processed.
        """
        return pulumi.get(self, "stream_last_delete_processed_at")

    @stream_last_delete_processed_at.setter
    def stream_last_delete_processed_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "stream_last_delete_processed_at", value)

    @property
    @pulumi.getter(name="streamLastInsertProcessedAt")
    def stream_last_insert_processed_at(self) -> Optional[pulumi.Input[str]]:
        """
        ISO-8601 date when new insert from source was last processed.
        """
        return pulumi.get(self, "stream_last_insert_processed_at")

    @stream_last_insert_processed_at.setter
    def stream_last_insert_processed_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "stream_last_insert_processed_at", value)

    @property
    @pulumi.getter(name="streamLastUpdateProcessedAt")
    def stream_last_update_processed_at(self) -> Optional[pulumi.Input[str]]:
        """
        ISO-8601 date when update from source was last processed.
        """
        return pulumi.get(self, "stream_last_update_processed_at")

    @stream_last_update_processed_at.setter
    def stream_last_update_processed_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "stream_last_update_processed_at", value)

    @property
    @pulumi.getter(name="streamRecordsDeleted")
    def stream_records_deleted(self) -> Optional[pulumi.Input[int]]:
        """
        Number of new records deleted using stream.
        """
        return pulumi.get(self, "stream_records_deleted")

    @stream_records_deleted.setter
    def stream_records_deleted(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "stream_records_deleted", value)

    @property
    @pulumi.getter(name="streamRecordsInserted")
    def stream_records_inserted(self) -> Optional[pulumi.Input[int]]:
        """
        Number of new records inserted using stream.
        """
        return pulumi.get(self, "stream_records_inserted")

    @stream_records_inserted.setter
    def stream_records_inserted(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "stream_records_inserted", value)

    @property
    @pulumi.getter(name="streamRecordsUpdated")
    def stream_records_updated(self) -> Optional[pulumi.Input[int]]:
        """
        Number of new records updated using stream.
        """
        return pulumi.get(self, "stream_records_updated")

    @stream_records_updated.setter
    def stream_records_updated(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "stream_records_updated", value)


@pulumi.input_type
class QueryLambdaSqlArgs:
    def __init__(__self__, *,
                 query: pulumi.Input[str],
                 default_parameters: Optional[pulumi.Input[Sequence[pulumi.Input['QueryLambdaSqlDefaultParameterArgs']]]] = None):
        pulumi.set(__self__, "query", query)
        if default_parameters is not None:
            pulumi.set(__self__, "default_parameters", default_parameters)

    @property
    @pulumi.getter
    def query(self) -> pulumi.Input[str]:
        return pulumi.get(self, "query")

    @query.setter
    def query(self, value: pulumi.Input[str]):
        pulumi.set(self, "query", value)

    @property
    @pulumi.getter(name="defaultParameters")
    def default_parameters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['QueryLambdaSqlDefaultParameterArgs']]]]:
        return pulumi.get(self, "default_parameters")

    @default_parameters.setter
    def default_parameters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['QueryLambdaSqlDefaultParameterArgs']]]]):
        pulumi.set(self, "default_parameters", value)


@pulumi.input_type
class QueryLambdaSqlDefaultParameterArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 type: pulumi.Input[str],
                 value: pulumi.Input[str]):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class RolePrivilegeArgs:
    def __init__(__self__, *,
                 action: pulumi.Input[str],
                 cluster: Optional[pulumi.Input[str]] = None,
                 resource_name: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] action: The action allowed by this privilege.
        :param pulumi.Input[str] cluster: Rockset cluster ID for which this action is allowed. Only valid for Workspace actions. Use '*ALL*' for actions which apply to all clusters.
        :param pulumi.Input[str] resource_name: The resource on which this action is allowed. Defaults to 'All' if not specified.
        """
        pulumi.set(__self__, "action", action)
        if cluster is not None:
            pulumi.set(__self__, "cluster", cluster)
        if resource_name is not None:
            pulumi.set(__self__, "resource_name", resource_name)

    @property
    @pulumi.getter
    def action(self) -> pulumi.Input[str]:
        """
        The action allowed by this privilege.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: pulumi.Input[str]):
        pulumi.set(self, "action", value)

    @property
    @pulumi.getter
    def cluster(self) -> Optional[pulumi.Input[str]]:
        """
        Rockset cluster ID for which this action is allowed. Only valid for Workspace actions. Use '*ALL*' for actions which apply to all clusters.
        """
        return pulumi.get(self, "cluster")

    @cluster.setter
    def cluster(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster", value)

    @property
    @pulumi.getter(name="resourceName")
    def resource_name(self) -> Optional[pulumi.Input[str]]:
        """
        The resource on which this action is allowed. Defaults to 'All' if not specified.
        """
        return pulumi.get(self, "resource_name")

    @resource_name.setter
    def resource_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_name", value)


@pulumi.input_type
class S3CollectionSourceArgs:
    def __init__(__self__, *,
                 bucket: pulumi.Input[str],
                 format: pulumi.Input[str],
                 integration_name: pulumi.Input[str],
                 csv: Optional[pulumi.Input['S3CollectionSourceCsvArgs']] = None,
                 pattern: Optional[pulumi.Input[str]] = None,
                 prefix: Optional[pulumi.Input[str]] = None,
                 xml: Optional[pulumi.Input['S3CollectionSourceXmlArgs']] = None):
        """
        :param pulumi.Input[str] bucket: S3 bucket containing the target data.
        :param pulumi.Input[str] format: Format of the data. One of: json, csv, xml. xml and csv blocks can only be set for their respective formats.
        :param pulumi.Input[str] integration_name: The name of the Rockset S3 integration. If no S3 integration is provided only data in public S3 buckets are accessible.
        :param pulumi.Input[str] pattern: Regex path pattern to S3 keys.
        :param pulumi.Input[str] prefix: Simple path prefix to S3 keys.
        """
        pulumi.set(__self__, "bucket", bucket)
        pulumi.set(__self__, "format", format)
        pulumi.set(__self__, "integration_name", integration_name)
        if csv is not None:
            pulumi.set(__self__, "csv", csv)
        if pattern is not None:
            pulumi.set(__self__, "pattern", pattern)
        if prefix is not None:
            warnings.warn("""use pattern instead""", DeprecationWarning)
            pulumi.log.warn("""prefix is deprecated: use pattern instead""")
        if prefix is not None:
            pulumi.set(__self__, "prefix", prefix)
        if xml is not None:
            pulumi.set(__self__, "xml", xml)

    @property
    @pulumi.getter
    def bucket(self) -> pulumi.Input[str]:
        """
        S3 bucket containing the target data.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: pulumi.Input[str]):
        pulumi.set(self, "bucket", value)

    @property
    @pulumi.getter
    def format(self) -> pulumi.Input[str]:
        """
        Format of the data. One of: json, csv, xml. xml and csv blocks can only be set for their respective formats.
        """
        return pulumi.get(self, "format")

    @format.setter
    def format(self, value: pulumi.Input[str]):
        pulumi.set(self, "format", value)

    @property
    @pulumi.getter(name="integrationName")
    def integration_name(self) -> pulumi.Input[str]:
        """
        The name of the Rockset S3 integration. If no S3 integration is provided only data in public S3 buckets are accessible.
        """
        return pulumi.get(self, "integration_name")

    @integration_name.setter
    def integration_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "integration_name", value)

    @property
    @pulumi.getter
    def csv(self) -> Optional[pulumi.Input['S3CollectionSourceCsvArgs']]:
        return pulumi.get(self, "csv")

    @csv.setter
    def csv(self, value: Optional[pulumi.Input['S3CollectionSourceCsvArgs']]):
        pulumi.set(self, "csv", value)

    @property
    @pulumi.getter
    def pattern(self) -> Optional[pulumi.Input[str]]:
        """
        Regex path pattern to S3 keys.
        """
        return pulumi.get(self, "pattern")

    @pattern.setter
    def pattern(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pattern", value)

    @property
    @pulumi.getter
    def prefix(self) -> Optional[pulumi.Input[str]]:
        """
        Simple path prefix to S3 keys.
        """
        warnings.warn("""use pattern instead""", DeprecationWarning)
        pulumi.log.warn("""prefix is deprecated: use pattern instead""")

        return pulumi.get(self, "prefix")

    @prefix.setter
    def prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "prefix", value)

    @property
    @pulumi.getter
    def xml(self) -> Optional[pulumi.Input['S3CollectionSourceXmlArgs']]:
        return pulumi.get(self, "xml")

    @xml.setter
    def xml(self, value: Optional[pulumi.Input['S3CollectionSourceXmlArgs']]):
        pulumi.set(self, "xml", value)


@pulumi.input_type
class S3CollectionSourceCsvArgs:
    def __init__(__self__, *,
                 column_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 column_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 encoding: Optional[pulumi.Input[str]] = None,
                 escape_char: Optional[pulumi.Input[str]] = None,
                 first_line_as_column_names: Optional[pulumi.Input[bool]] = None,
                 quote_char: Optional[pulumi.Input[str]] = None,
                 separator: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[str]]] column_names: The names of the columns.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] column_types: The types of the columns.
        :param pulumi.Input[str] encoding: Can be one of: UTF-8, ISO*8859*1, UTF-16.
        :param pulumi.Input[str] escape_char: Escape character removes any special meaning from the character that follows it. Defaults to backslash.
        :param pulumi.Input[bool] first_line_as_column_names: If the first line in every object specifies the column names.
        :param pulumi.Input[str] quote_char: Character within which a cell value is enclosed. Defaults to double quote.
        :param pulumi.Input[str] separator: A single character that is the column separator.
        """
        if column_names is not None:
            pulumi.set(__self__, "column_names", column_names)
        if column_types is not None:
            pulumi.set(__self__, "column_types", column_types)
        if encoding is not None:
            pulumi.set(__self__, "encoding", encoding)
        if escape_char is not None:
            pulumi.set(__self__, "escape_char", escape_char)
        if first_line_as_column_names is not None:
            pulumi.set(__self__, "first_line_as_column_names", first_line_as_column_names)
        if quote_char is not None:
            pulumi.set(__self__, "quote_char", quote_char)
        if separator is not None:
            pulumi.set(__self__, "separator", separator)

    @property
    @pulumi.getter(name="columnNames")
    def column_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The names of the columns.
        """
        return pulumi.get(self, "column_names")

    @column_names.setter
    def column_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "column_names", value)

    @property
    @pulumi.getter(name="columnTypes")
    def column_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The types of the columns.
        """
        return pulumi.get(self, "column_types")

    @column_types.setter
    def column_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "column_types", value)

    @property
    @pulumi.getter
    def encoding(self) -> Optional[pulumi.Input[str]]:
        """
        Can be one of: UTF-8, ISO*8859*1, UTF-16.
        """
        return pulumi.get(self, "encoding")

    @encoding.setter
    def encoding(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "encoding", value)

    @property
    @pulumi.getter(name="escapeChar")
    def escape_char(self) -> Optional[pulumi.Input[str]]:
        """
        Escape character removes any special meaning from the character that follows it. Defaults to backslash.
        """
        return pulumi.get(self, "escape_char")

    @escape_char.setter
    def escape_char(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "escape_char", value)

    @property
    @pulumi.getter(name="firstLineAsColumnNames")
    def first_line_as_column_names(self) -> Optional[pulumi.Input[bool]]:
        """
        If the first line in every object specifies the column names.
        """
        return pulumi.get(self, "first_line_as_column_names")

    @first_line_as_column_names.setter
    def first_line_as_column_names(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "first_line_as_column_names", value)

    @property
    @pulumi.getter(name="quoteChar")
    def quote_char(self) -> Optional[pulumi.Input[str]]:
        """
        Character within which a cell value is enclosed. Defaults to double quote.
        """
        return pulumi.get(self, "quote_char")

    @quote_char.setter
    def quote_char(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "quote_char", value)

    @property
    @pulumi.getter
    def separator(self) -> Optional[pulumi.Input[str]]:
        """
        A single character that is the column separator.
        """
        return pulumi.get(self, "separator")

    @separator.setter
    def separator(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "separator", value)


@pulumi.input_type
class S3CollectionSourceXmlArgs:
    def __init__(__self__, *,
                 attribute_prefix: Optional[pulumi.Input[str]] = None,
                 doc_tag: Optional[pulumi.Input[str]] = None,
                 encoding: Optional[pulumi.Input[str]] = None,
                 root_tag: Optional[pulumi.Input[str]] = None,
                 value_tag: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] attribute_prefix: Tag to differentiate between attributes and elements.
        :param pulumi.Input[str] doc_tag: Tags with which documents are identified
        :param pulumi.Input[str] encoding: Can be one of: UTF-8, ISO*8859*1, UTF-16.
        :param pulumi.Input[str] root_tag: Tag until which xml is ignored.
        :param pulumi.Input[str] value_tag: Tag used for the value when there are attributes in the element having no child.
        """
        if attribute_prefix is not None:
            pulumi.set(__self__, "attribute_prefix", attribute_prefix)
        if doc_tag is not None:
            pulumi.set(__self__, "doc_tag", doc_tag)
        if encoding is not None:
            pulumi.set(__self__, "encoding", encoding)
        if root_tag is not None:
            pulumi.set(__self__, "root_tag", root_tag)
        if value_tag is not None:
            pulumi.set(__self__, "value_tag", value_tag)

    @property
    @pulumi.getter(name="attributePrefix")
    def attribute_prefix(self) -> Optional[pulumi.Input[str]]:
        """
        Tag to differentiate between attributes and elements.
        """
        return pulumi.get(self, "attribute_prefix")

    @attribute_prefix.setter
    def attribute_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "attribute_prefix", value)

    @property
    @pulumi.getter(name="docTag")
    def doc_tag(self) -> Optional[pulumi.Input[str]]:
        """
        Tags with which documents are identified
        """
        return pulumi.get(self, "doc_tag")

    @doc_tag.setter
    def doc_tag(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "doc_tag", value)

    @property
    @pulumi.getter
    def encoding(self) -> Optional[pulumi.Input[str]]:
        """
        Can be one of: UTF-8, ISO*8859*1, UTF-16.
        """
        return pulumi.get(self, "encoding")

    @encoding.setter
    def encoding(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "encoding", value)

    @property
    @pulumi.getter(name="rootTag")
    def root_tag(self) -> Optional[pulumi.Input[str]]:
        """
        Tag until which xml is ignored.
        """
        return pulumi.get(self, "root_tag")

    @root_tag.setter
    def root_tag(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "root_tag", value)

    @property
    @pulumi.getter(name="valueTag")
    def value_tag(self) -> Optional[pulumi.Input[str]]:
        """
        Tag used for the value when there are attributes in the element having no child.
        """
        return pulumi.get(self, "value_tag")

    @value_tag.setter
    def value_tag(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value_tag", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetUserResult',
    'AwaitableGetUserResult',
    'get_user',
    'get_user_output',
]

@pulumi.output_type
class GetUserResult:
    """
    A collection of values returned by getUser.
    """
    def __init__(__self__, email=None, first_name=None, id=None, last_name=None, roles=None, state=None):
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if first_name and not isinstance(first_name, str):
            raise TypeError("Expected argument 'first_name' to be a str")
        pulumi.set(__self__, "first_name", first_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_name and not isinstance(last_name, str):
            raise TypeError("Expected argument 'last_name' to be a str")
        pulumi.set(__self__, "last_name", last_name)
        if roles and not isinstance(roles, list):
            raise TypeError("Expected argument 'roles' to be a list")
        pulumi.set(__self__, "roles", roles)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter
    def email(self) -> str:
        """
        User email.
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="firstName")
    def first_name(self) -> str:
        """
        User's first name.
        """
        return pulumi.get(self, "first_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The user ID, in the form of the `email`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lastName")
    def last_name(self) -> str:
        """
        User's last name.
        """
        return pulumi.get(self, "last_name")

    @property
    @pulumi.getter
    def roles(self) -> Sequence[str]:
        """
        List of roles for the user. E.g. 'admin', 'member', 'read-only'.
        """
        return pulumi.get(self, "roles")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        State of the user, either NEW or ACTIVE.
        """
        return pulumi.get(self, "state")


class AwaitableGetUserResult(GetUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserResult(
            email=self.email,
            first_name=self.first_name,
            id=self.id,
            last_name=self.last_name,
            roles=self.roles,
            state=self.state)


def get_user(email: Optional[str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserResult:
    """
    This data source can be used to fetch information about a specific user.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_rockset as rockset

    pme = rockset.get_user(email="pme@rockset.com")
    ```


    :param str email: User email.
    """
    __args__ = dict()
    __args__['email'] = email
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('rockset:index/getUser:getUser', __args__, opts=opts, typ=GetUserResult).value

    return AwaitableGetUserResult(
        email=pulumi.get(__ret__, 'email'),
        first_name=pulumi.get(__ret__, 'first_name'),
        id=pulumi.get(__ret__, 'id'),
        last_name=pulumi.get(__ret__, 'last_name'),
        roles=pulumi.get(__ret__, 'roles'),
        state=pulumi.get(__ret__, 'state'))


@_utilities.lift_output_func(get_user)
def get_user_output(email: Optional[pulumi.Input[str]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetUserResult]:
    """
    This data source can be used to fetch information about a specific user.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_rockset as rockset

    pme = rockset.get_user(email="pme@rockset.com")
    ```


    :param str email: User email.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetQueryLambdaTagResult',
    'AwaitableGetQueryLambdaTagResult',
    'get_query_lambda_tag',
    'get_query_lambda_tag_output',
]

@pulumi.output_type
class GetQueryLambdaTagResult:
    """
    A collection of values returned by getQueryLambdaTag.
    """
    def __init__(__self__, description=None, id=None, last_executed=None, name=None, sql=None, tag=None, version=None, workspace=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_executed and not isinstance(last_executed, str):
            raise TypeError("Expected argument 'last_executed' to be a str")
        pulumi.set(__self__, "last_executed", last_executed)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if sql and not isinstance(sql, str):
            raise TypeError("Expected argument 'sql' to be a str")
        pulumi.set(__self__, "sql", sql)
        if tag and not isinstance(tag, str):
            raise TypeError("Expected argument 'tag' to be a str")
        pulumi.set(__self__, "tag", tag)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)
        if workspace and not isinstance(workspace, str):
            raise TypeError("Expected argument 'workspace' to be a str")
        pulumi.set(__self__, "workspace", workspace)

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Description of the query lambda.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lastExecuted")
    def last_executed(self) -> str:
        """
        Last time the query lambda was executed.
        """
        return pulumi.get(self, "last_executed")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the query lambda.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def sql(self) -> str:
        """
        Query lambda SQL.
        """
        return pulumi.get(self, "sql")

    @property
    @pulumi.getter
    def tag(self) -> str:
        """
        Tag name.
        """
        return pulumi.get(self, "tag")

    @property
    @pulumi.getter
    def version(self) -> str:
        """
        Query lambda tag version.
        """
        return pulumi.get(self, "version")

    @property
    @pulumi.getter
    def workspace(self) -> str:
        """
        Workspace the query lambda resides in.
        """
        return pulumi.get(self, "workspace")


class AwaitableGetQueryLambdaTagResult(GetQueryLambdaTagResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetQueryLambdaTagResult(
            description=self.description,
            id=self.id,
            last_executed=self.last_executed,
            name=self.name,
            sql=self.sql,
            tag=self.tag,
            version=self.version,
            workspace=self.workspace)


def get_query_lambda_tag(name: Optional[str] = None,
                         tag: Optional[str] = None,
                         workspace: Optional[str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetQueryLambdaTagResult:
    """
    Use this data source to access information about an existing resource.

    :param str name: Name of the query lambda.
    :param str tag: Tag name.
    :param str workspace: Workspace the query lambda resides in.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['tag'] = tag
    __args__['workspace'] = workspace
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('rockset:index/getQueryLambdaTag:getQueryLambdaTag', __args__, opts=opts, typ=GetQueryLambdaTagResult).value

    return AwaitableGetQueryLambdaTagResult(
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        last_executed=pulumi.get(__ret__, 'last_executed'),
        name=pulumi.get(__ret__, 'name'),
        sql=pulumi.get(__ret__, 'sql'),
        tag=pulumi.get(__ret__, 'tag'),
        version=pulumi.get(__ret__, 'version'),
        workspace=pulumi.get(__ret__, 'workspace'))


@_utilities.lift_output_func(get_query_lambda_tag)
def get_query_lambda_tag_output(name: Optional[pulumi.Input[str]] = None,
                                tag: Optional[pulumi.Input[str]] = None,
                                workspace: Optional[pulumi.Input[str]] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetQueryLambdaTagResult]:
    """
    Use this data source to access information about an existing resource.

    :param str name: Name of the query lambda.
    :param str tag: Tag name.
    :param str workspace: Workspace the query lambda resides in.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['VirtualInstanceArgs', 'VirtualInstance']

@pulumi.input_type
class VirtualInstanceArgs:
    def __init__(__self__, *,
                 size: pulumi.Input[str],
                 auto_suspend_seconds: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 mount_refresh_interval_seconds: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 remount_on_resume: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a VirtualInstance resource.
        :param pulumi.Input[str] size: Requested virtual instance size. Note that this field is called type in the API documentation.
        :param pulumi.Input[int] auto_suspend_seconds: Number of seconds without queries after which the Virtual Instance is suspended.
        :param pulumi.Input[str] description: Description of the virtual instance.
        :param pulumi.Input[int] mount_refresh_interval_seconds: Number of seconds between data refreshes for mounts on this Virtual Instance. A value of 0 means continuous refresh and a value of null means never refresh.
        :param pulumi.Input[str] name: Name of the virtual instance.
        :param pulumi.Input[bool] remount_on_resume: When a Virtual Instance is resumed, remount all collections that were mounted when the Virtual Instance was suspended.
        """
        pulumi.set(__self__, "size", size)
        if auto_suspend_seconds is not None:
            pulumi.set(__self__, "auto_suspend_seconds", auto_suspend_seconds)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if mount_refresh_interval_seconds is not None:
            pulumi.set(__self__, "mount_refresh_interval_seconds", mount_refresh_interval_seconds)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if remount_on_resume is not None:
            pulumi.set(__self__, "remount_on_resume", remount_on_resume)

    @property
    @pulumi.getter
    def size(self) -> pulumi.Input[str]:
        """
        Requested virtual instance size. Note that this field is called type in the API documentation.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: pulumi.Input[str]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter(name="autoSuspendSeconds")
    def auto_suspend_seconds(self) -> Optional[pulumi.Input[int]]:
        """
        Number of seconds without queries after which the Virtual Instance is suspended.
        """
        return pulumi.get(self, "auto_suspend_seconds")

    @auto_suspend_seconds.setter
    def auto_suspend_seconds(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "auto_suspend_seconds", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the virtual instance.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="mountRefreshIntervalSeconds")
    def mount_refresh_interval_seconds(self) -> Optional[pulumi.Input[int]]:
        """
        Number of seconds between data refreshes for mounts on this Virtual Instance. A value of 0 means continuous refresh and a value of null means never refresh.
        """
        return pulumi.get(self, "mount_refresh_interval_seconds")

    @mount_refresh_interval_seconds.setter
    def mount_refresh_interval_seconds(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "mount_refresh_interval_seconds", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the virtual instance.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="remountOnResume")
    def remount_on_resume(self) -> Optional[pulumi.Input[bool]]:
        """
        When a Virtual Instance is resumed, remount all collections that were mounted when the Virtual Instance was suspended.
        """
        return pulumi.get(self, "remount_on_resume")

    @remount_on_resume.setter
    def remount_on_resume(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "remount_on_resume", value)


@pulumi.input_type
class _VirtualInstanceState:
    def __init__(__self__, *,
                 auto_suspend_seconds: Optional[pulumi.Input[int]] = None,
                 current_size: Optional[pulumi.Input[str]] = None,
                 default: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 desired_size: Optional[pulumi.Input[str]] = None,
                 monitoring_enabled: Optional[pulumi.Input[bool]] = None,
                 mount_refresh_interval_seconds: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 remount_on_resume: Optional[pulumi.Input[bool]] = None,
                 rrn: Optional[pulumi.Input[str]] = None,
                 size: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering VirtualInstance resources.
        :param pulumi.Input[int] auto_suspend_seconds: Number of seconds without queries after which the Virtual Instance is suspended.
        :param pulumi.Input[str] current_size: Current size of the virtual instance.
        :param pulumi.Input[bool] default: Is this Virtual Instance the default.
        :param pulumi.Input[str] description: Description of the virtual instance.
        :param pulumi.Input[str] desired_size: Desired size of the virtual instance.
        :param pulumi.Input[bool] monitoring_enabled: Is monitoring enabled for this Virtual Instance.
        :param pulumi.Input[int] mount_refresh_interval_seconds: Number of seconds between data refreshes for mounts on this Virtual Instance. A value of 0 means continuous refresh and a value of null means never refresh.
        :param pulumi.Input[str] name: Name of the virtual instance.
        :param pulumi.Input[bool] remount_on_resume: When a Virtual Instance is resumed, remount all collections that were mounted when the Virtual Instance was suspended.
        :param pulumi.Input[str] rrn: RRN of this Virtual Instance.
        :param pulumi.Input[str] size: Requested virtual instance size. Note that this field is called type in the API documentation.
        :param pulumi.Input[str] state: Virtual Instance state.
        """
        if auto_suspend_seconds is not None:
            pulumi.set(__self__, "auto_suspend_seconds", auto_suspend_seconds)
        if current_size is not None:
            pulumi.set(__self__, "current_size", current_size)
        if default is not None:
            pulumi.set(__self__, "default", default)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if desired_size is not None:
            pulumi.set(__self__, "desired_size", desired_size)
        if monitoring_enabled is not None:
            pulumi.set(__self__, "monitoring_enabled", monitoring_enabled)
        if mount_refresh_interval_seconds is not None:
            pulumi.set(__self__, "mount_refresh_interval_seconds", mount_refresh_interval_seconds)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if remount_on_resume is not None:
            pulumi.set(__self__, "remount_on_resume", remount_on_resume)
        if rrn is not None:
            pulumi.set(__self__, "rrn", rrn)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="autoSuspendSeconds")
    def auto_suspend_seconds(self) -> Optional[pulumi.Input[int]]:
        """
        Number of seconds without queries after which the Virtual Instance is suspended.
        """
        return pulumi.get(self, "auto_suspend_seconds")

    @auto_suspend_seconds.setter
    def auto_suspend_seconds(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "auto_suspend_seconds", value)

    @property
    @pulumi.getter(name="currentSize")
    def current_size(self) -> Optional[pulumi.Input[str]]:
        """
        Current size of the virtual instance.
        """
        return pulumi.get(self, "current_size")

    @current_size.setter
    def current_size(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "current_size", value)

    @property
    @pulumi.getter
    def default(self) -> Optional[pulumi.Input[bool]]:
        """
        Is this Virtual Instance the default.
        """
        return pulumi.get(self, "default")

    @default.setter
    def default(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "default", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the virtual instance.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="desiredSize")
    def desired_size(self) -> Optional[pulumi.Input[str]]:
        """
        Desired size of the virtual instance.
        """
        return pulumi.get(self, "desired_size")

    @desired_size.setter
    def desired_size(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "desired_size", value)

    @property
    @pulumi.getter(name="monitoringEnabled")
    def monitoring_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Is monitoring enabled for this Virtual Instance.
        """
        return pulumi.get(self, "monitoring_enabled")

    @monitoring_enabled.setter
    def monitoring_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "monitoring_enabled", value)

    @property
    @pulumi.getter(name="mountRefreshIntervalSeconds")
    def mount_refresh_interval_seconds(self) -> Optional[pulumi.Input[int]]:
        """
        Number of seconds between data refreshes for mounts on this Virtual Instance. A value of 0 means continuous refresh and a value of null means never refresh.
        """
        return pulumi.get(self, "mount_refresh_interval_seconds")

    @mount_refresh_interval_seconds.setter
    def mount_refresh_interval_seconds(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "mount_refresh_interval_seconds", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the virtual instance.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="remountOnResume")
    def remount_on_resume(self) -> Optional[pulumi.Input[bool]]:
        """
        When a Virtual Instance is resumed, remount all collections that were mounted when the Virtual Instance was suspended.
        """
        return pulumi.get(self, "remount_on_resume")

    @remount_on_resume.setter
    def remount_on_resume(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "remount_on_resume", value)

    @property
    @pulumi.getter
    def rrn(self) -> Optional[pulumi.Input[str]]:
        """
        RRN of this Virtual Instance.
        """
        return pulumi.get(self, "rrn")

    @rrn.setter
    def rrn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rrn", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[str]]:
        """
        Requested virtual instance size. Note that this field is called type in the API documentation.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        Virtual Instance state.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)


class VirtualInstance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_suspend_seconds: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 mount_refresh_interval_seconds: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 remount_on_resume: Optional[pulumi.Input[bool]] = None,
                 size: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Rockset Virtual Instance. To be able to create a new Virtual Instance,
        The main virtual instance must use a dedicated instance to create a secondary virtual instance,
        which must be SMALL or larger. To enable live mount, the secondary virtual instance must be MEDIUM or larger.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_rockset as rockset

        query = rockset.VirtualInstance("query",
            description="vi for executing query lambdas",
            size="MEDIUM",
            remount_on_resume=True)
        patch = rockset.CollectionMount("patch",
            virtual_instance_id=query.id,
            path="commons.data")
        ```

        ## Import

        ```sh
         $ pulumi import rockset:index/virtualInstance:VirtualInstance query 29e4a43c-fff4-4fe6-80e3-1ee57bc22e82
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] auto_suspend_seconds: Number of seconds without queries after which the Virtual Instance is suspended.
        :param pulumi.Input[str] description: Description of the virtual instance.
        :param pulumi.Input[int] mount_refresh_interval_seconds: Number of seconds between data refreshes for mounts on this Virtual Instance. A value of 0 means continuous refresh and a value of null means never refresh.
        :param pulumi.Input[str] name: Name of the virtual instance.
        :param pulumi.Input[bool] remount_on_resume: When a Virtual Instance is resumed, remount all collections that were mounted when the Virtual Instance was suspended.
        :param pulumi.Input[str] size: Requested virtual instance size. Note that this field is called type in the API documentation.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VirtualInstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Rockset Virtual Instance. To be able to create a new Virtual Instance,
        The main virtual instance must use a dedicated instance to create a secondary virtual instance,
        which must be SMALL or larger. To enable live mount, the secondary virtual instance must be MEDIUM or larger.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_rockset as rockset

        query = rockset.VirtualInstance("query",
            description="vi for executing query lambdas",
            size="MEDIUM",
            remount_on_resume=True)
        patch = rockset.CollectionMount("patch",
            virtual_instance_id=query.id,
            path="commons.data")
        ```

        ## Import

        ```sh
         $ pulumi import rockset:index/virtualInstance:VirtualInstance query 29e4a43c-fff4-4fe6-80e3-1ee57bc22e82
        ```

        :param str resource_name: The name of the resource.
        :param VirtualInstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VirtualInstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_suspend_seconds: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 mount_refresh_interval_seconds: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 remount_on_resume: Optional[pulumi.Input[bool]] = None,
                 size: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VirtualInstanceArgs.__new__(VirtualInstanceArgs)

            __props__.__dict__["auto_suspend_seconds"] = auto_suspend_seconds
            __props__.__dict__["description"] = description
            __props__.__dict__["mount_refresh_interval_seconds"] = mount_refresh_interval_seconds
            __props__.__dict__["name"] = name
            __props__.__dict__["remount_on_resume"] = remount_on_resume
            if size is None and not opts.urn:
                raise TypeError("Missing required property 'size'")
            __props__.__dict__["size"] = size
            __props__.__dict__["current_size"] = None
            __props__.__dict__["default"] = None
            __props__.__dict__["desired_size"] = None
            __props__.__dict__["monitoring_enabled"] = None
            __props__.__dict__["rrn"] = None
            __props__.__dict__["state"] = None
        super(VirtualInstance, __self__).__init__(
            'rockset:index/virtualInstance:VirtualInstance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_suspend_seconds: Optional[pulumi.Input[int]] = None,
            current_size: Optional[pulumi.Input[str]] = None,
            default: Optional[pulumi.Input[bool]] = None,
            description: Optional[pulumi.Input[str]] = None,
            desired_size: Optional[pulumi.Input[str]] = None,
            monitoring_enabled: Optional[pulumi.Input[bool]] = None,
            mount_refresh_interval_seconds: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None,
            remount_on_resume: Optional[pulumi.Input[bool]] = None,
            rrn: Optional[pulumi.Input[str]] = None,
            size: Optional[pulumi.Input[str]] = None,
            state: Optional[pulumi.Input[str]] = None) -> 'VirtualInstance':
        """
        Get an existing VirtualInstance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] auto_suspend_seconds: Number of seconds without queries after which the Virtual Instance is suspended.
        :param pulumi.Input[str] current_size: Current size of the virtual instance.
        :param pulumi.Input[bool] default: Is this Virtual Instance the default.
        :param pulumi.Input[str] description: Description of the virtual instance.
        :param pulumi.Input[str] desired_size: Desired size of the virtual instance.
        :param pulumi.Input[bool] monitoring_enabled: Is monitoring enabled for this Virtual Instance.
        :param pulumi.Input[int] mount_refresh_interval_seconds: Number of seconds between data refreshes for mounts on this Virtual Instance. A value of 0 means continuous refresh and a value of null means never refresh.
        :param pulumi.Input[str] name: Name of the virtual instance.
        :param pulumi.Input[bool] remount_on_resume: When a Virtual Instance is resumed, remount all collections that were mounted when the Virtual Instance was suspended.
        :param pulumi.Input[str] rrn: RRN of this Virtual Instance.
        :param pulumi.Input[str] size: Requested virtual instance size. Note that this field is called type in the API documentation.
        :param pulumi.Input[str] state: Virtual Instance state.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VirtualInstanceState.__new__(_VirtualInstanceState)

        __props__.__dict__["auto_suspend_seconds"] = auto_suspend_seconds
        __props__.__dict__["current_size"] = current_size
        __props__.__dict__["default"] = default
        __props__.__dict__["description"] = description
        __props__.__dict__["desired_size"] = desired_size
        __props__.__dict__["monitoring_enabled"] = monitoring_enabled
        __props__.__dict__["mount_refresh_interval_seconds"] = mount_refresh_interval_seconds
        __props__.__dict__["name"] = name
        __props__.__dict__["remount_on_resume"] = remount_on_resume
        __props__.__dict__["rrn"] = rrn
        __props__.__dict__["size"] = size
        __props__.__dict__["state"] = state
        return VirtualInstance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autoSuspendSeconds")
    def auto_suspend_seconds(self) -> pulumi.Output[Optional[int]]:
        """
        Number of seconds without queries after which the Virtual Instance is suspended.
        """
        return pulumi.get(self, "auto_suspend_seconds")

    @property
    @pulumi.getter(name="currentSize")
    def current_size(self) -> pulumi.Output[str]:
        """
        Current size of the virtual instance.
        """
        return pulumi.get(self, "current_size")

    @property
    @pulumi.getter
    def default(self) -> pulumi.Output[bool]:
        """
        Is this Virtual Instance the default.
        """
        return pulumi.get(self, "default")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Description of the virtual instance.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="desiredSize")
    def desired_size(self) -> pulumi.Output[str]:
        """
        Desired size of the virtual instance.
        """
        return pulumi.get(self, "desired_size")

    @property
    @pulumi.getter(name="monitoringEnabled")
    def monitoring_enabled(self) -> pulumi.Output[bool]:
        """
        Is monitoring enabled for this Virtual Instance.
        """
        return pulumi.get(self, "monitoring_enabled")

    @property
    @pulumi.getter(name="mountRefreshIntervalSeconds")
    def mount_refresh_interval_seconds(self) -> pulumi.Output[Optional[int]]:
        """
        Number of seconds between data refreshes for mounts on this Virtual Instance. A value of 0 means continuous refresh and a value of null means never refresh.
        """
        return pulumi.get(self, "mount_refresh_interval_seconds")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the virtual instance.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="remountOnResume")
    def remount_on_resume(self) -> pulumi.Output[Optional[bool]]:
        """
        When a Virtual Instance is resumed, remount all collections that were mounted when the Virtual Instance was suspended.
        """
        return pulumi.get(self, "remount_on_resume")

    @property
    @pulumi.getter
    def rrn(self) -> pulumi.Output[str]:
        """
        RRN of this Virtual Instance.
        """
        return pulumi.get(self, "rrn")

    @property
    @pulumi.getter
    def size(self) -> pulumi.Output[str]:
        """
        Requested virtual instance size. Note that this field is called type in the API documentation.
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        Virtual Instance state.
        """
        return pulumi.get(self, "state")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .alias import *
from .api_key import *
from .collection import *
from .collection_mount import *
from .dynamodb_collection import *
from .dynamodb_integration import *
from .gcs_collection import *
from .gcs_integration import *
from .get_account import *
from .get_query_lambda_tag import *
from .get_user import *
from .get_virtual_instance import *
from .get_workspace import *
from .kafka_collection import *
from .kafka_integration import *
from .kinesis_collection import *
from .kinesis_integration import *
from .mongodb_collection import *
from .mongodb_integration import *
from .provider import *
from .query_lambda import *
from .query_lambda_tag import *
from .role import *
from .s3_collection import *
from .s3_integration import *
from .user import *
from .view import *
from .virtual_instance import *
from .workspace import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_rockset.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_rockset.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "rockset",
  "mod": "index/alias",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/alias:Alias": "Alias"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/apiKey",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/apiKey:ApiKey": "ApiKey"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/collection",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/collection:Collection": "Collection"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/collectionMount",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/collectionMount:CollectionMount": "CollectionMount"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/dynamodbCollection",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/dynamodbCollection:DynamodbCollection": "DynamodbCollection"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/dynamodbIntegration",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/dynamodbIntegration:DynamodbIntegration": "DynamodbIntegration"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/gcsCollection",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/gcsCollection:GcsCollection": "GcsCollection"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/gcsIntegration",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/gcsIntegration:GcsIntegration": "GcsIntegration"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/kafkaCollection",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/kafkaCollection:KafkaCollection": "KafkaCollection"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/kafkaIntegration",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/kafkaIntegration:KafkaIntegration": "KafkaIntegration"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/kinesisCollection",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/kinesisCollection:KinesisCollection": "KinesisCollection"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/kinesisIntegration",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/kinesisIntegration:KinesisIntegration": "KinesisIntegration"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/mongodbCollection",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/mongodbCollection:MongodbCollection": "MongodbCollection"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/mongodbIntegration",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/mongodbIntegration:MongodbIntegration": "MongodbIntegration"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/queryLambda",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/queryLambda:QueryLambda": "QueryLambda"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/queryLambdaTag",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/queryLambdaTag:QueryLambdaTag": "QueryLambdaTag"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/role",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/role:Role": "Role"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/s3Collection",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/s3Collection:S3Collection": "S3Collection"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/s3Integration",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/s3Integration:S3Integration": "S3Integration"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/user",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/user:User": "User"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/view",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/view:View": "View"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/virtualInstance",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/virtualInstance:VirtualInstance": "VirtualInstance"
  }
 },
 {
  "pkg": "rockset",
  "mod": "index/workspace",
  "fqn": "pulumi_rockset",
  "classes": {
   "rockset:index/workspace:Workspace": "Workspace"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "rockset",
  "token": "pulumi:providers:rockset",
  "fqn": "pulumi_rockset",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RoleArgs', 'Role']

@pulumi.input_type
class RoleArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 privileges: Optional[pulumi.Input[Sequence[pulumi.Input['RolePrivilegeArgs']]]] = None):
        """
        The set of arguments for constructing a Role resource.
        :param pulumi.Input[str] description: Role description.
        :param pulumi.Input[str] name: Role name.
        :param pulumi.Input[Sequence[pulumi.Input['RolePrivilegeArgs']]] privileges: Privileges associated with the role. For a full list see [API documentation](https://rockset.com/docs/iam/#supported-privileges)
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if privileges is not None:
            pulumi.set(__self__, "privileges", privileges)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Role description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Role name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def privileges(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RolePrivilegeArgs']]]]:
        """
        Privileges associated with the role. For a full list see [API documentation](https://rockset.com/docs/iam/#supported-privileges)
        """
        return pulumi.get(self, "privileges")

    @privileges.setter
    def privileges(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RolePrivilegeArgs']]]]):
        pulumi.set(self, "privileges", value)


@pulumi.input_type
class _RoleState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[str]] = None,
                 created_by: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 owner_email: Optional[pulumi.Input[str]] = None,
                 privileges: Optional[pulumi.Input[Sequence[pulumi.Input['RolePrivilegeArgs']]]] = None):
        """
        Input properties used for looking up and filtering Role resources.
        :param pulumi.Input[str] created_at: When the role was created.
        :param pulumi.Input[str] created_by: Who created the role.
        :param pulumi.Input[str] description: Role description.
        :param pulumi.Input[str] name: Role name.
        :param pulumi.Input[str] owner_email: The email of the user who currently owns the role.
        :param pulumi.Input[Sequence[pulumi.Input['RolePrivilegeArgs']]] privileges: Privileges associated with the role. For a full list see [API documentation](https://rockset.com/docs/iam/#supported-privileges)
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if owner_email is not None:
            pulumi.set(__self__, "owner_email", owner_email)
        if privileges is not None:
            pulumi.set(__self__, "privileges", privileges)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        When the role was created.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[str]]:
        """
        Who created the role.
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_by", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Role description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Role name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="ownerEmail")
    def owner_email(self) -> Optional[pulumi.Input[str]]:
        """
        The email of the user who currently owns the role.
        """
        return pulumi.get(self, "owner_email")

    @owner_email.setter
    def owner_email(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner_email", value)

    @property
    @pulumi.getter
    def privileges(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RolePrivilegeArgs']]]]:
        """
        Privileges associated with the role. For a full list see [API documentation](https://rockset.com/docs/iam/#supported-privileges)
        """
        return pulumi.get(self, "privileges")

    @privileges.setter
    def privileges(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RolePrivilegeArgs']]]]):
        pulumi.set(self, "privileges", value)


class Role(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 privileges: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RolePrivilegeArgs']]]]] = None,
                 __props__=None):
        """
        Manages a Rockset [Role](https://rockset.com/docs/iam/).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_rockset as rockset

        query_only_role = rockset.Role("query-onlyRole",
            description="This role can only query collections in the prod workspace in the usw2a1 cluster",
            privileges=[
                rockset.RolePrivilegeArgs(
                    action="QUERY_DATA_WS",
                    resource_name="prod",
                    cluster="usw2a1",
                ),
                rockset.RolePrivilegeArgs(
                    action="EXECUTE_QUERY_LAMBDA_WS",
                    resource_name="prod",
                    cluster="usw2a1",
                ),
            ])
        query_only_api_key = rockset.ApiKey("query-onlyApiKey", role=query_only_role.name)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Role description.
        :param pulumi.Input[str] name: Role name.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RolePrivilegeArgs']]]] privileges: Privileges associated with the role. For a full list see [API documentation](https://rockset.com/docs/iam/#supported-privileges)
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[RoleArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Rockset [Role](https://rockset.com/docs/iam/).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_rockset as rockset

        query_only_role = rockset.Role("query-onlyRole",
            description="This role can only query collections in the prod workspace in the usw2a1 cluster",
            privileges=[
                rockset.RolePrivilegeArgs(
                    action="QUERY_DATA_WS",
                    resource_name="prod",
                    cluster="usw2a1",
                ),
                rockset.RolePrivilegeArgs(
                    action="EXECUTE_QUERY_LAMBDA_WS",
                    resource_name="prod",
                    cluster="usw2a1",
                ),
            ])
        query_only_api_key = rockset.ApiKey("query-onlyApiKey", role=query_only_role.name)
        ```

        :param str resource_name: The name of the resource.
        :param RoleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RoleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 privileges: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RolePrivilegeArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RoleArgs.__new__(RoleArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            __props__.__dict__["privileges"] = privileges
            __props__.__dict__["created_at"] = None
            __props__.__dict__["created_by"] = None
            __props__.__dict__["owner_email"] = None
        super(Role, __self__).__init__(
            'rockset:index/role:Role',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            created_by: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            owner_email: Optional[pulumi.Input[str]] = None,
            privileges: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RolePrivilegeArgs']]]]] = None) -> 'Role':
        """
        Get an existing Role resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] created_at: When the role was created.
        :param pulumi.Input[str] created_by: Who created the role.
        :param pulumi.Input[str] description: Role description.
        :param pulumi.Input[str] name: Role name.
        :param pulumi.Input[str] owner_email: The email of the user who currently owns the role.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RolePrivilegeArgs']]]] privileges: Privileges associated with the role. For a full list see [API documentation](https://rockset.com/docs/iam/#supported-privileges)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RoleState.__new__(_RoleState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["owner_email"] = owner_email
        __props__.__dict__["privileges"] = privileges
        return Role(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        When the role was created.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[str]:
        """
        Who created the role.
        """
        return pulumi.get(self, "created_by")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Role description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Role name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="ownerEmail")
    def owner_email(self) -> pulumi.Output[str]:
        """
        The email of the user who currently owns the role.
        """
        return pulumi.get(self, "owner_email")

    @property
    @pulumi.getter
    def privileges(self) -> pulumi.Output[Optional[Sequence['outputs.RolePrivilege']]]:
        """
        Privileges associated with the role. For a full list see [API documentation](https://rockset.com/docs/iam/#supported-privileges)
        """
        return pulumi.get(self, "privileges")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['ApiKeyArgs', 'ApiKey']

@pulumi.input_type
class ApiKeyArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ApiKey resource.
        :param pulumi.Input[str] name: Name of the api key.
        :param pulumi.Input[str] role: The role the api key will use. If not specified, "All User Assigned Roles" will be used.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if role is not None:
            pulumi.set(__self__, "role", role)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the api key.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[str]]:
        """
        The role the api key will use. If not specified, "All User Assigned Roles" will be used.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role", value)


@pulumi.input_type
class _ApiKeyState:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 user: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ApiKey resources.
        :param pulumi.Input[str] key: The resulting Rockset api key.
        :param pulumi.Input[str] name: Name of the api key.
        :param pulumi.Input[str] role: The role the api key will use. If not specified, "All User Assigned Roles" will be used.
        :param pulumi.Input[str] user: The user the key is created for.
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if role is not None:
            pulumi.set(__self__, "role", role)
        if user is not None:
            pulumi.set(__self__, "user", user)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[str]]:
        """
        The resulting Rockset api key.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the api key.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[str]]:
        """
        The role the api key will use. If not specified, "All User Assigned Roles" will be used.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role", value)

    @property
    @pulumi.getter
    def user(self) -> Optional[pulumi.Input[str]]:
        """
        The user the key is created for.
        """
        return pulumi.get(self, "user")

    @user.setter
    def user(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user", value)


class ApiKey(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manage a Rockset Api Key.

        Can be used together with roles to scope the actions the api key can take.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: Name of the api key.
        :param pulumi.Input[str] role: The role the api key will use. If not specified, "All User Assigned Roles" will be used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ApiKeyArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manage a Rockset Api Key.

        Can be used together with roles to scope the actions the api key can take.

        :param str resource_name: The name of the resource.
        :param ApiKeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApiKeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApiKeyArgs.__new__(ApiKeyArgs)

            __props__.__dict__["name"] = name
            __props__.__dict__["role"] = role
            __props__.__dict__["key"] = None
            __props__.__dict__["user"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["key"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ApiKey, __self__).__init__(
            'rockset:index/apiKey:ApiKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            key: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            role: Optional[pulumi.Input[str]] = None,
            user: Optional[pulumi.Input[str]] = None) -> 'ApiKey':
        """
        Get an existing ApiKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] key: The resulting Rockset api key.
        :param pulumi.Input[str] name: Name of the api key.
        :param pulumi.Input[str] role: The role the api key will use. If not specified, "All User Assigned Roles" will be used.
        :param pulumi.Input[str] user: The user the key is created for.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApiKeyState.__new__(_ApiKeyState)

        __props__.__dict__["key"] = key
        __props__.__dict__["name"] = name
        __props__.__dict__["role"] = role
        __props__.__dict__["user"] = user
        return ApiKey(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def key(self) -> pulumi.Output[str]:
        """
        The resulting Rockset api key.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the api key.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def role(self) -> pulumi.Output[Optional[str]]:
        """
        The role the api key will use. If not specified, "All User Assigned Roles" will be used.
        """
        return pulumi.get(self, "role")

    @property
    @pulumi.getter
    def user(self) -> pulumi.Output[str]:
        """
        The user the key is created for.
        """
        return pulumi.get(self, "user")

